# vim: set ts=4 sw=4 et:

%if 0%{?suse_version} >= 1120
%define with_pulse 1
%else
%define with_pulse 0
%endif

Name:           cmus
Version:        2.4.3
Release:        1.4
Summary:        Curses-based Ogg, MP3, WMA, and WAV Player
Source:         http://prdownloads.sourceforge.net/cmus/cmus-v%{version}.tar.bz2
Source1:        cmus.desktop
Source2:        cmus.png
Patch1:         cmus-rc_ao_default_output_plugin.patch
URL:            http://cmus.sourceforge.net/
Group:          Productivity/Multimedia/Sound/Players
License:        GNU General Public License version 2 (GPL v2)
BuildRoot:      %{_tmppath}/build-%{name}-%{version}
BuildRequires:  ncurses-devel
BuildRequires:  mad-devel
BuildRequires:  flac-devel
BuildRequires:  libmodplug-devel
BuildRequires:  libmpcdec-devel
BuildRequires:  libmp4v2-devel
BuildRequires:  libvorbis-devel libogg-devel
BuildRequires:  wavpack-devel
BuildRequires:  faad2-devel
BuildRequires:  libffmpeg-devel xvid-devel x264-devel
BuildRequires:  alsa-devel
BuildRequires:  libao-devel
BuildRequires:  gcc make glibc-devel
BuildRequires:  update-desktop-files
%if %with_pulse
BuildRequires:  libpulse-devel >= 0.9.19
Recommends:     %{name}-plugin-pulse = %{version}-%{release}
%endif #with_pulse
Recommends:     %{name}-plugin-aac = %{version}-%{release}
Recommends:     %{name}-plugin-ffmpeg = %{version}-%{release}
Recommends:     %{name}-plugin-mad = %{version}-%{release}
Recommends:     %{name}-plugin-mp4 = %{version}-%{release}
Recommends:     %{name}-plugin-mpc = %{version}-%{release}
Recommends:     %{name}-plugin-wavpack = %{version}-%{release}

%description
CMus is a small and fast text mode music player for Linux and *BSD. Supported
file formats include FLAC, Ogg, MP3 (via libmad), wav, and all module formats
supported by libmodplug. Included output plugins are ALSA, ARTS, OSS, and
Sun. It can be controlled through a UNIX socket. Background playlist loading
and a metadata cache make loading files very fast. Playqueue, playlist filters
and directory browser. Three playlist views are available: artist/album/track,
shuffle list, and sorted list. There are three play modes: all, artist, album.

%if %with_pulse
%package plugin-pulse
Summary:        Pulseaudio Output Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-pulse
This package proves Pulseaudio output support for the %{name} music player.
It may be removed to avoid unwanted system dependencies on Pulseaudio.
%endif #with_pulse

%package plugin-aac
Summary:        AAC Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-aac
This package proves AAC input support for the %{name} music player.

%package plugin-ffmpeg
Summary:        FFmpeg Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-ffmpeg
This package proves ffmpeg input support for the %{name} music player.

%package plugin-mad
Summary:        Mad MP3 Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-mad
This package proves mad (MP3) input support for the %{name} music player.

%package plugin-modplug
Summary:        Modplug Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-modplug
This package proves modplug (mod files) input support for the %{name}
music player.

%package plugin-mp4
Summary:        MP4 Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-mp4
This package proves MP4 input support for the %{name} music player.

%package plugin-mpc
Summary:        MPC (Musepack) Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-mpc
This package proves MPC (Musepack) input support for the %{name} music player.

%package plugin-wavpack
Summary:        Wavpack Input Plugin for the %{name} Music Player
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%description plugin-wavpack
This package proves wavpack input support for the %{name} music player.

%package plugins-all
Summary:        Installs all %{name} plugins
Group:          Productivity/Multimedia/Sound/Players
Requires:       %{name} = %{version}-%{release}
%if %with_pulse
Requires:       %{name}-plugin-pulse = %{version}-%{release}
%endif #with_pulse
Requires:       %{name}-plugin-aac = %{version}-%{release}
Requires:       %{name}-plugin-ffmpeg = %{version}-%{release}
Requires:       %{name}-plugin-mad = %{version}-%{release}
Requires:       %{name}-plugin-mp4 = %{version}-%{release}
Requires:       %{name}-plugin-mpc = %{version}-%{release}
Requires:       %{name}-plugin-wavpack = %{version}-%{release}
%description plugins-all
This package pulls in all the plugins for %{name}.


%prep
%setup -q -n "cmus-v%{version}"
%patch1

%build
# not autoconf
./configure \
    prefix="%{_prefix}" \
    bindir="%{_bindir}" \
    datadir="%{_datadir}" \
    libdir="%{_libdir}" \
    mandir="%{_mandir}" \
    exampledir="%{_docdir}/%{name}/examples" \
    CONFIG_{ALSA,AO,FLAC,MAD,MODPLUG,MPC,VORBIS,WAV,WAVPACK,MP4,AAC,FFMPEG}=y \
    CONFIG_{ARTS,SUN,WAVEOUT}=n \
    CFLAGS="%{optflags}"

%__make %{?_smp_flags} V=2

%install
%makeinstall

%__mv "%{buildroot}%{_datadir}/cmus/rc.orig" \
      "%{buildroot}%{_datadir}/cmus/rc.dist"

%__install -D -m0644 "%{SOURCE1}" "%{buildroot}%{_datadir}/applications/%{name}.desktop"
%__install -D -m0644 "%{SOURCE2}" "%{buildroot}%{_datadir}/pixmaps/cmus.png"
%suse_update_desktop_file -r "%{name}" AudioVideo Player

%__chmod 0644 cmus-status-display

cat<<EOF >README.plugins-all
This subpackage is empty but requires all the available %{name} plugin packages
EOF

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING README
%doc cmus-status-display
%{_bindir}/cmus
%{_bindir}/cmus-remote
%dir %{_libdir}/cmus
%dir %{_libdir}/cmus/ip
%{_libdir}/cmus/ip/flac.so
%{_libdir}/cmus/ip/vorbis.so
%{_libdir}/cmus/ip/wav.so
%dir %{_libdir}/cmus/op
%{_libdir}/cmus/op/alsa.so
%{_libdir}/cmus/op/ao.so
%{_libdir}/cmus/op/oss.so
%dir %{_datadir}/cmus
%{_datadir}/cmus/*.theme
%config(noreplace) %{_datadir}/cmus/rc
%{_datadir}/cmus/rc.dist
%doc %{_mandir}/man1/cmus*.1%{ext_man}
%doc %{_mandir}/man7/cmus-tutorial.7%{ext_man}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/cmus.png

%if %with_pulse
%files plugin-pulse
%defattr(-,root,root)
%{_libdir}/cmus/op/pulse.so
%endif #with_pulse

%files plugin-aac
%defattr(-,root,root)
%{_libdir}/cmus/ip/aac.so

%files plugin-ffmpeg
%defattr(-,root,root)
%{_libdir}/cmus/ip/ffmpeg.so

%files plugin-mad
%defattr(-,root,root)
%{_libdir}/cmus/ip/mad.so

%files plugin-modplug
%defattr(-,root,root)
%{_libdir}/cmus/ip/modplug.so

%files plugin-mp4
%defattr(-,root,root)
%{_libdir}/cmus/ip/mp4.so

%files plugin-mpc
%defattr(-,root,root)
%{_libdir}/cmus/ip/mpc.so

%files plugin-wavpack
%defattr(-,root,root)
%{_libdir}/cmus/ip/wavpack.so

%files plugins-all
%defattr(-,root,root)
%doc README.plugins-all

%changelog
* Wed Nov 30 2011 pascal.bleser@opensuse.org
- update to 2.4.3:
  * maintenance release: it mostly fixes several build and stability issues
    caused by external library changes
* Sun Jul 24 2011 pascal.bleser@opensuse.org
- update to 2.4.2:
  * several important bug and build fixes; everyone is encouraged to upgrade
* Thu May 26 2011 pascal.bleser@opensuse.org
- update to 2.4.1:
  * fixes crashes and misbehaviours
* Sun Apr 24 2011 detlef@links2linux.de
- update to 2.4.0:
  * this release features tons of improvements, with most notable ones being
    live library/playlist filtering and playback resume support
* Sun Apr 10 2011 pascal.bleser@opensuse.org
- update to 2.3.5:
  * several serious (but rarely encountered) issues have been fixed
- build with optflags
* Thu Feb 10 2011 pascal.bleser@opensuse.org
- update to 2.3.4:
  * features an ability to restore the playback volume after restart (when
    using PulseAudio output plugin)
  * adds APE files support (using the FFMPEG input plugin)
  * bugfixes
* Thu Jun 17 2010 pascal@links2linux.de
- update to 2.3.3:
  * a couple of serious bugs has been fixed, so everybody is encouraged to
    upgrade
  * support for the newest version of mp4v2 was added
* Thu Apr 15 2010 pascal@links2linux.de
- update to 2.3.2:
  * libao 1.0 compatibility issue are fixed
* Sun Mar 14 2010 pascal.bleser@opensuse.org
- update to 2.3.1:
  * ID3 parsing was fixed
  * a minor documentation update was done
  * MP3s with broken CRC are now supported
  * a default binding was set for "q"
  * insecure /tmp usage was fixed
* Tue Mar  2 2010 pascal.bleser@opensuse.org
- update to 2.3.0
* Sat Jul 28 2007 guru@unixtech.be
- new package
